@@ -5,7 +5,7 @@
 // +---------------------------------------------------------------------------+
 // | geeklog/plugins/dataproxy/drivers/staticpages.class.php                   |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2007-2010 mystral-kk - geeklog AT mystral-kk DOT net        |
+// | Copyright (C) 2007-2011 mystral-kk - geeklog AT mystral-kk DOT net        |
 // |                                                                           |
 // | Constructed with the Universal Plugin                                     |
 // | Copyright (C) 2002 by the following authors:                              |
@@ -37,7 +37,29 @@ if (strpos(strtolower($_SERVER['PHP_SELF']), 'staticpages.class.php') !== FALSE)
 
 class Dataproxy_staticpages extends DataproxyDriver
 {
-	var $driver_name = 'staticpages';
+	public $driver_name = 'staticpages';
+	public $_isSP162 = FALSE;	// Whether Staticpages-1.6.2 or later
+	
+	/**
+	* Constructor
+	*
+	* @param $parent    ref. to an object
+	* @param $uid       int                0 (= Root), 1(= anon), user id
+	* @param $encoding  string             encoding of the content
+	* @param $options   array
+	*/
+	public function __construct(&$parent, $uid = 1, $encoding = 'utf-8',
+			$options = array())
+	{
+		global $_TABLES;
+		
+		parent::__construct($parent, $uid, $encoding, $options);
+		
+		$pi_version = DB_getItem(
+			$_TABLES['plugins'], 'pi_version', "pi_name = 'staticpages'"
+		);
+		$this->_isSP162 = (version_compare($pi_version, '1.6.2') >= 0);
+	}
 	
 	/**
 	* Returns array of (
@@ -49,7 +71,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 	*   'raw_data'  => raw data of the item (stripslashed)
 	* )
 	*/
-	function getItemById($id, $all_langs = false)
+	public function getItemById($id, $all_langs = FALSE)
 	{
 	    global $_CONF, $_TABLES;
 		
@@ -58,16 +80,23 @@ class Dataproxy_staticpages extends DataproxyDriver
 		$sql = "SELECT * "
 			 . "FROM {$_TABLES['staticpage']} "
 			 . "WHERE (sp_id = '" . addslashes($id) . "') ";
+		
+		if ($this->_isSP162) {
+			$sql .= "AND (draft_flag = 0) ";
+		}
+		
 		if ($this->uid > 0) {
 			$sql .= COM_getPermSql('AND', $this->uid);
 		}
+		
 		$result = DB_query($sql);
+		
 		if (DB_error()) {
 			return $retval;
 		}
 		
 		if (DB_numRows($result) == 1) {
-			$A = DB_fetchArray($result, false);
+			$A = DB_fetchArray($result, FALSE);
 			$A = array_map('stripslashes', $A);
 			
 			$retval['id']        = $id;
@@ -83,7 +112,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 				$retval['date'] = strtotime($A['sp_date']);
 			}
 			
-			$retval['image_uri'] = false;
+			$retval['image_uri'] = FALSE;
 			$retval['raw_data']  = $A;
 		}
 		
@@ -103,7 +132,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 	*   'image_uri' => $image_uri (string)
 	* )
 	*/
-	function getItems($category, $all_langs = false)
+	public function getItems($category, $all_langs = FALSE)
 	{
 		global $_CONF, $_TABLES, $_SP_CONF;
 		
@@ -111,12 +140,16 @@ class Dataproxy_staticpages extends DataproxyDriver
 		
 		if ($this->_isGL170) {
 			$sql = "SELECT sp_id, sp_title, UNIX_TIMESTAMP(modified) AS day "
-				 . "FROM {$_TABLES['staticpage']} "
-				 . "WHERE (1 = 1) ";
+				 . "FROM {$_TABLES['staticpage']} ";
 		} else {
 			$sql = "SELECT sp_id, sp_title, UNIX_TIMESTAMP(sp_date) AS day "
-				 . "FROM {$_TABLES['staticpage']} "
-				 . "WHERE (1 = 1) ";
+				 . "FROM {$_TABLES['staticpage']} ";
+		}
+		
+		if ($this->_isSP162) {
+			$sql .= "WHERE (draft_flag = 0) ";
+		} else {
+			$sql .= "WHERE (1 = 1) ";
 		}
 		
 		if ($this->uid > 0) {
@@ -128,6 +161,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 		} else {
 			$crit = 'id';
 		}
+		
 		$crit = 'sp_' . $crit;
 		
 		if ($this->_isGL170 AND ($crit === 'sp_date')) {
@@ -135,13 +169,13 @@ class Dataproxy_staticpages extends DataproxyDriver
 		}
 		
 		$sql .= " ORDER BY " . $crit;
-		
 		$result = DB_query($sql);
+		
 		if (DB_error()) {
 			return $entries;
 		}
 		
-		while (($A = DB_fetchArray($result, false)) !== false) {
+		while (($A = DB_fetchArray($result, FALSE)) !== FALSE) {
 			$entry = array();
 			$entry['id']        = stripslashes($A['sp_id']);
 			$entry['title']     = stripslashes($A['sp_title']);
@@ -150,7 +184,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 				. rawurlencode($entry['id'])
 			);
 			$entry['date']      = $A['day'];
-			$entry['image_uri'] = false;
+			$entry['image_uri'] = FALSE;
 			$entries[] = $entry;
 		}
 		
@@ -170,7 +204,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 	*   'image_uri' => $image_uri (string)
 	* )
 	*/
-	function getItemsByDate($category = '', $all_langs = false)
+	public function getItemsByDate($category = '', $all_langs = FALSE)
 	{
 		global $_CONF, $_TABLES, $_SP_CONF;
 		
@@ -190,6 +224,10 @@ class Dataproxy_staticpages extends DataproxyDriver
 				 . "WHERE (UNIX_TIMESTAMP(sp_date) BETWEEN '$this->startdate' AND '$this->enddate') ";
 		}
 		
+		if ($this->_isSP162) {
+			$sql .= "AND (draft_flag = 0) ";
+		}
+		
 		if ($this->uid > 0) {
 			$sql .= COM_getPermSql('AND', $this->uid);
 		}
@@ -199,6 +237,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 		} else {
 			$crit = 'id';
 		}
+		
 		$crit = 'sp_' . $crit;
 		
 		if ($this->_isGL170 AND ($crit === 'sp_date')) {
@@ -206,13 +245,13 @@ class Dataproxy_staticpages extends DataproxyDriver
 		}
 		
 		$sql .= " ORDER BY " . $crit;
-		
 		$result = DB_query($sql);
+		
 		if (DB_error()) {
 			return $entries;
 		}
 		
-		while (($A = DB_fetchArray($result, false)) !== false) {
+		while (($A = DB_fetchArray($result, FALSE)) !== FALSE) {
 			$entry = array();
 			$entry['id']        = stripslashes($A['sp_id']);
 			$entry['title']     = stripslashes($A['sp_title']);
@@ -221,7 +260,7 @@ class Dataproxy_staticpages extends DataproxyDriver
 				. rawurlencode($entry['id'])
 			);
 			$entry['date']      = $A['day'];
-			$entry['image_uri'] = false;
+			$entry['image_uri'] = FALSE;
 			$entries[] = $entry;
 		}
 		
