@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.6                                                               |
+// | Geeklog 1.8                                                               |
 // +---------------------------------------------------------------------------+
 // | story.php                                                                 |
 // |                                                                           |
 // | Geeklog story administration page.                                        |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2010 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -245,7 +245,7 @@ function liststories($current_topic = '')
 function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
 {
     global $_CONF, $_TABLES, $_USER, $LANG24, $LANG_ACCESS, $LANG_ADMIN,
-           $MESSAGE;
+           $MESSAGE, $_SCRIPTS;
 
     $display = '';
 
@@ -253,11 +253,8 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         $_CONF['hour_mode'] = 12;
     }
 
-    if (!empty ($errormsg)) {
-        $display .= COM_startBlock($LANG24[25], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $errormsg;
-        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+    if (!empty($errormsg)) {
+        $display .= COM_showMessageText($errormsg, $LANG24[25]);
     }
 
     if (!empty ($currenttopic)) {
@@ -283,41 +280,50 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
             }
         }
         $result = $story->loadFromArgsArray($_POST);
+
+        // in preview mode, we now need to re-insert the images
+        if ($_CONF['maximagesperarticle'] > 0) {
+            $errors = $story->insertImages();
+            if (count($errors) > 0) {
+                $msg = $LANG24[55] . LB . '<ul>' . LB;
+                foreach ($errors as $err) {
+                    $msg .= '<li>' . $err . '</li>' . LB;
+                }
+                $msg .= '</ul>' . LB;
+                $display .= COM_showMessageText($msg, $LANG24[54]);
+            }
+        }
     } else {
         $result = $story->loadFromDatabase($sid, $mode);
     }
 
-    if( ($result == STORY_PERMISSION_DENIED) || ($result == STORY_NO_ACCESS_PARAMS) )
-    {
-        $display .= COM_startBlock($LANG_ACCESS['accessdenied'], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $LANG24[42];
-        $display .= COM_endBlock(COM_getBlockTemplate ('_msg_block', 'footer'));
+    if (($result == STORY_PERMISSION_DENIED) ||
+            ($result == STORY_NO_ACCESS_PARAMS)) {
+        $display .= COM_showMessageText($LANG24[42],
+                                        $LANG_ACCESS['accessdenied']);
         COM_accessLog("User {$_USER['username']} tried to illegally access story $sid.");
         return $display;
-    } elseif( ($result == STORY_EDIT_DENIED) || ($result == STORY_EXISTING_NO_EDIT_PERMISSION) ) {
-        $display .= COM_startBlock($LANG_ACCESS['accessdenied'], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-        $display .= $LANG24[41];
-        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+    } elseif (($result == STORY_EDIT_DENIED) ||
+            ($result == STORY_EXISTING_NO_EDIT_PERMISSION)) {
+        $display .= COM_showMessageText($LANG24[41],
+                                        $LANG_ACCESS['accessdenied']);
         $display .= STORY_renderArticle ($story, 'p');
         COM_accessLog("User {$_USER['username']} tried to illegally edit story $sid.");
         return $display;
-    } elseif( $result == STORY_INVALID_SID ) {
-        if( $mode == 'editsubmission' )
-        {
+    } elseif ($result == STORY_INVALID_SID) {
+        if ($mode == 'editsubmission') {
             // that submission doesn't seem to be there any more (may have been
             // handled by another Admin) - take us back to the moderation page
-            return COM_refresh( $_CONF['site_admin_url'] . '/moderation.php' );
+            return COM_refresh($_CONF['site_admin_url'] . '/moderation.php');
         } else {
-            return COM_refresh( $_CONF['site_admin_url'] . '/story.php' );
+            return COM_refresh($_CONF['site_admin_url'] . '/story.php');
         }
-    } elseif( $result == STORY_DUPLICATE_SID) {
+    } elseif ($result == STORY_DUPLICATE_SID) {
         $display .= COM_showMessageText($LANG24[24]);
     }
 
     // Load HTML templates
-    $story_templates = new Template($_CONF['path_layout'] . 'admin/story');
+    $story_templates = COM_newTemplate($_CONF['path_layout'] . 'admin/story');
     if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
         $thtml = $_CONF['path_layout'] . 'admin/story/storyeditor_advanced.' . $_CONF['language'] . '.thtml';
         if (file_exists($thtml)) {
@@ -358,11 +364,7 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         $story_templates->set_file('editor', $thtml);
         $advanced_editormode = false;
     }
-    $story_templates->set_var('xhtml', XHTML);
-    $story_templates->set_var('site_url',       $_CONF['site_url']);
-    $story_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
-    $story_templates->set_var('layout_url',     $_CONF['layout_url']);
-    $story_templates->set_var('hour_mode',      $_CONF['hour_mode']);
+     $story_templates->set_var('hour_mode',      $_CONF['hour_mode']);
 
     if ($story->hasContent()) {
         $previewContent = STORY_renderArticle($story, 'p');
@@ -533,7 +535,7 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     if ($story->EditElements('statuscode') == STORY_ARCHIVE_ON_EXPIRE) {
         $story_templates->set_var('is_checked2', 'checked="checked"');
         $story_templates->set_var('is_checked3', 'checked="checked"');
-        $story_templates->set_var('showarchivedisabled', 'false');
+        $js_showarchivedisabled = 'false';
         $have_archive_topic = true; // force display of auto archive option
     } elseif ($story->EditElements('statuscode') == STORY_DELETE_ON_EXPIRE) {
         $story_templates->set_var('is_checked2', 'checked="checked"');
@@ -541,12 +543,12 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         if (! $have_archive_topic) {
             $story_templates->set_var('is_checked3', 'style="display:none;"');
         }
-        $story_templates->set_var('showarchivedisabled', 'false');
+        $js_showarchivedisabled = 'false';
     } else {
         if (! $have_archive_topic) {
             $story_templates->set_var('is_checked3', 'style="display:none;"');
         }
-        $story_templates->set_var('showarchivedisabled', 'true');
+        $js_showarchivedisabled = 'true';
     }
     $story_templates->set_var('lang_archivetitle', $LANG24[58]);
     $story_templates->set_var('lang_option', $LANG24[59]);
@@ -609,9 +611,9 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $story_templates->set_var('lang_cmt_disable', $LANG24[63]);
     if ($story->EditElements('cmt_close')) {
         $story_templates->set_var('is_checked5', 'checked="checked"');
-        $story_templates->set_var('showcmtclosedisabled', 'false');
+        $js_showcmtclosedisabled = 'false';
     } else {
-        $story_templates->set_var('showcmtclosedisabled', 'true');
+        $js_showcmtclosedisabled = 'true';
     }
 
     $month_options = COM_getMonthFormOptions($story->EditElements('cmt_close_month'));
@@ -684,8 +686,8 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $story_templates->set_var('lang_bodytext', $LANG24[17]);
     $story_templates->set_var('lang_postmode', $LANG24[4]);
     $story_templates->set_var('lang_publishoptions',$LANG24[76]);
-    $story_templates->set_var('lang_nojavascript',$LANG24[77]);
-    $story_templates->set_var('no_javascript_return_link',sprintf($LANG24[78],$_CONF['site_admin_url'], $sid));
+    $story_templates->set_var('noscript', COM_getNoScript(false, $LANG24[77], sprintf($LANG24[78],$_CONF['site_admin_url'], $sid)));
+    
     $post_options = COM_optionList($_TABLES['postmodes'],'code,name',$story->EditElements('postmode'));
 
     // If Advanced Mode - add post option and set default if editing story created with Advanced Editor
@@ -738,6 +740,85 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         }
         $fileinputs .= $LANG24[28] . '<br' . XHTML . '>';
     }
+    
+    // *****************************************    
+    // Add JavaScript
+    if (!$advanced_editormode) {
+        $js = '<script type="text/javascript">
+        //<![CDATA[
+        function enablearchive(obj) {
+            var f = obj.form;           // all elements have their parent form in "form"
+            var disable = obj.checked;  // Disable when checked
+            if (f.elements["archiveflag"].checked==true && f.elements["storycode11"].checked==false) {
+                f.elements["storycode10"].checked=true;
+            }
+            f.elements["storycode10"].disabled=!disable;
+            f.elements["storycode11"].disabled=!disable;
+            f.elements["expire_month"].disabled=!disable;
+            f.elements["expire_day"].disabled=!disable;
+            f.elements["expire_year"].disabled=!disable;
+            f.elements["expire_hour"].disabled=!disable;
+            f.elements["expire_minute"].disabled=!disable;
+            f.elements["expire_ampm"].disabled=!disable;
+        }
+            
+            function enablecmtclose(obj) {
+            var f = obj.form;           // all elements have their parent form in "form"
+            var disable = obj.checked;  // Disable when checked
+        
+            f.elements["cmt_close_month"].disabled=!disable;
+            f.elements["cmt_close_day"].disabled=!disable;
+            f.elements["cmt_close_year"].disabled=!disable;
+            f.elements["cmt_close_hour"].disabled=!disable;
+            f.elements["cmt_close_minute"].disabled=!disable;
+            f.elements["cmt_close_ampm"].disabled=!disable;
+            
+        }
+        //]]>
+        </script>' . LB;
+    } else {
+        $js = '<script type="text/javascript">
+            // Setup editor path for FCKeditor JS Functions
+            geeklogEditorBasePath = "' . $_CONF['site_url'] . '/fckeditor/";
+        </script>' . LB;
+
+        $js .= '<!-- Hide the Advanced Editor as Javascript is required. If JS is enabled then the JS below will un-hide it -->
+        <script type="text/javascript">
+            document.getElementById("advanced_editor").style.display=""
+        </script>';     
+        
+        $_SCRIPTS->setJavaScriptFile('advanced_editor', '/javascript/advanced_editor.js');
+        $_SCRIPTS->setJavaScriptFile('storyeditor_fckeditor', '/javascript/storyeditor_fckeditor.js');        
+    }
+    
+    $js .= '<script type="text/javascript">
+    <!-- This code will only be executed by a browser that supports Javascript -->
+    var jstest = ' . $js_showarchivedisabled . ';
+    var jstest2 = ' . $js_showcmtclosedisabled . ';
+    if (jstest) {
+        document.frmstory.expire_month.disabled=true;
+        document.frmstory.expire_day.disabled=true;
+        document.frmstory.expire_year.disabled=true;
+        document.frmstory.expire_hour.disabled=true;
+        document.frmstory.expire_minute.disabled=true;
+        document.frmstory.expire_ampm.disabled=true;
+        document.frmstory.storycode10.disabled=true;
+        document.frmstory.storycode11.disabled=true;
+    }
+    if (jstest2) {
+        document.frmstory.cmt_close_month.disabled=true;
+        document.frmstory.cmt_close_day.disabled=true;
+        document.frmstory.cmt_close_year.disabled=true;
+        document.frmstory.cmt_close_hour.disabled=true;
+        document.frmstory.cmt_close_minute.disabled=true;
+        document.frmstory.cmt_close_ampm.disabled=true;
+    }
+    </script>';    
+    
+    $_SCRIPTS->setJavaScript($js);
+    
+    // *****************************************
+    
     $story_templates->set_var('saved_images', $saved_images);
     $story_templates->set_var('image_form_elements', $fileinputs);
     $story_templates->set_var('lang_hits', $LANG24[18]);
